Author: mvw
Date: 2008-02-29 08:44:07-0800
New Revision: 14168

Modified:
   trunk/src/app/src/org/argouml/application/api/AbstractArgoJPanel.java
   trunk/src/app/src/org/argouml/ui/DetailsPane.java
   trunk/src/app/src/org/argouml/ui/explorer/ExplorerPopup.java
   trunk/src/app/src/org/argouml/uml/diagram/DiagramUndoManager.java
   trunk/src/app/src/org/argouml/uml/diagram/sequence/ui/FigHead.java
   trunk/src/app/src/org/argouml/uml/diagram/state/ui/FigHistoryState.java
   trunk/src/app/src/org/argouml/uml/diagram/ui/FigNodeModelElement.java
   trunk/src/app/src/org/argouml/uml/diagram/ui/FigStereotypesCompartment.java
   trunk/src/app/src/org/argouml/uml/ui/TabStyle.java
   trunk/src/app/src/org/argouml/uml/ui/UMLModelElementListModel2.java
   
trunk/src/app/src/org/argouml/uml/ui/foundation/extension_mechanisms/PropPanelStereotype.java

Log:
Style only.

Modified: trunk/src/app/src/org/argouml/application/api/AbstractArgoJPanel.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/application/api/AbstractArgoJPanel.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/application/api/AbstractArgoJPanel.java&p2=trunk/src/app/src/org/argouml/application/api/AbstractArgoJPanel.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/application/api/AbstractArgoJPanel.java       
(original)
+++ trunk/src/app/src/org/argouml/application/api/AbstractArgoJPanel.java       
2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 1996-2007 The Regents of the University of California. All
+// Copyright (c) 1996-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -172,10 +172,10 @@
     }
 
     /**
-     * @param icon this icon will be shown in front of the title
+     * @param theIcon this icon will be shown in front of the title
      */
-    public void setIcon(Icon icon) {
-        this.icon = icon;
+    public void setIcon(Icon theIcon) {
+        this.icon = theIcon;
     }
 
     ////////////////////////////////////////////////////////////////

Modified: trunk/src/app/src/org/argouml/ui/DetailsPane.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/ui/DetailsPane.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/ui/DetailsPane.java&p2=trunk/src/app/src/org/argouml/ui/DetailsPane.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/ui/DetailsPane.java   (original)
+++ trunk/src/app/src/org/argouml/ui/DetailsPane.java   2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 1996-2007 The Regents of the University of California. All
+// Copyright (c) 1996-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -423,7 +423,7 @@
      * @return the tab instance for the given class
      */
     public AbstractArgoJPanel getTab(
-            Class<? extends AbstractArgoJPanel> tabClass) {
+            Class< ? extends AbstractArgoJPanel> tabClass) {
         for (JPanel tab : tabPanelList) {
             if (tab.getClass().equals(tabClass)) {
                 return (AbstractArgoJPanel) tab;

Modified: trunk/src/app/src/org/argouml/ui/explorer/ExplorerPopup.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/ui/explorer/ExplorerPopup.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/ui/explorer/ExplorerPopup.java&p2=trunk/src/app/src/org/argouml/ui/explorer/ExplorerPopup.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/ui/explorer/ExplorerPopup.java        
(original)
+++ trunk/src/app/src/org/argouml/ui/explorer/ExplorerPopup.java        
2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 1996-2007 The Regents of the University of California. All
+// Copyright (c) 1996-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -558,18 +558,19 @@
            Logger.getLogger(ActionCreateModelElement.class);
        
        public ActionCreateModelElement(
-               Object metaType, 
-               Object source, 
-               Object dest,
+               Object theMetaType, 
+               Object theSource, 
+               Object theDestination,
                String relationshipDescr) {
            super(MessageFormat.format(
-                   relationshipDescr,
-                   new Object[] {
-                           DisplayTextTree.getModelElementDisplayName(source),
-                           DisplayTextTree.getModelElementDisplayName(dest)}));
-           this.metaType = metaType;
-           this.source = source;
-           this.dest = dest;
+               relationshipDescr,
+                new Object[] {
+                    DisplayTextTree.getModelElementDisplayName(theSource),
+                    DisplayTextTree.getModelElementDisplayName(
+                            theDestination)}));
+           this.metaType = theMetaType;
+           this.source = theSource;
+           this.dest = theDestination;
        }
 
        public void actionPerformed(ActionEvent e) {
@@ -604,12 +605,12 @@
            Logger.getLogger(ActionCreateModelElement.class);
        
        public ActionCreateAssociation(
-               Object metaType, 
-               List classifiers) {
+               Object theMetaType, 
+               List classifiersList) {
            super(menuLocalize("menu.popup.create") + " "
-                   + Model.getMetaTypes().getName(metaType));
-           this.metaType = metaType;
-           this.classifiers = classifiers;
+                   + Model.getMetaTypes().getName(theMetaType));
+           this.metaType = theMetaType;
+           this.classifiers = classifiersList;
        }
 
        public void actionPerformed(ActionEvent e) {
@@ -653,12 +654,12 @@
             Logger.getLogger(ActionCreateModelElement.class);
 
         public ActionCreateAssociationRole(
-                Object metaType, 
-                List classifierRoles) {
+                Object theMetaType, 
+                List classifierRolesList) {
             super(menuLocalize("menu.popup.create") + " "
-                    + Model.getMetaTypes().getName(metaType));
-            this.metaType = metaType;
-            this.classifierRoles = classifierRoles;
+                    + Model.getMetaTypes().getName(theMetaType));
+            this.metaType = theMetaType;
+            this.classifierRoles = classifierRolesList;
         }
 
         public void actionPerformed(ActionEvent e) {

Modified: trunk/src/app/src/org/argouml/uml/diagram/DiagramUndoManager.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/diagram/DiagramUndoManager.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/diagram/DiagramUndoManager.java&p2=trunk/src/app/src/org/argouml/uml/diagram/DiagramUndoManager.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/uml/diagram/DiagramUndoManager.java   
(original)
+++ trunk/src/app/src/org/argouml/uml/diagram/DiagramUndoManager.java   
2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 2007 The Regents of the University of California. All
+// Copyright (c) 2007-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -85,8 +85,8 @@
         
         private final Memento memento;
         
-        DiagramCommand(final Memento memento) {
-            this.memento = memento;
+        DiagramCommand(final Memento theMemento) {
+            this.memento = theMemento;
         }
 
         @Override

Modified: trunk/src/app/src/org/argouml/uml/diagram/sequence/ui/FigHead.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/diagram/sequence/ui/FigHead.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/diagram/sequence/ui/FigHead.java&p2=trunk/src/app/src/org/argouml/uml/diagram/sequence/ui/FigHead.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/uml/diagram/sequence/ui/FigHead.java  
(original)
+++ trunk/src/app/src/org/argouml/uml/diagram/sequence/ui/FigHead.java  
2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 1996-2006 The Regents of the University of California. All
+// Copyright (c) 1996-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -44,20 +44,20 @@
     /**
      * Constructor.
      *
-     * @param stereotypeFig
-     * @param nameFig
+     * @param stereotype
+     * @param name
      */
-    FigHead(Fig stereotypeFig, FigText nameFig) {
-        this.stereotypeFig = stereotypeFig;
-        this.nameFig = nameFig;
+    FigHead(Fig stereotype, FigText name) {
+        this.stereotypeFig = stereotype;
+        this.nameFig = name;
         rectFig =
             new FigRect(0, 0,
                 FigClassifierRole.MIN_HEAD_WIDTH,
                 FigClassifierRole.MIN_HEAD_HEIGHT,
                 Color.black, Color.white);
         addFig(rectFig);
-        addFig(nameFig);
-        addFig(stereotypeFig);
+        addFig(name);
+        addFig(stereotype);
     }
 
     /*

Modified: 
trunk/src/app/src/org/argouml/uml/diagram/state/ui/FigHistoryState.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/diagram/state/ui/FigHistoryState.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/diagram/state/ui/FigHistoryState.java&p2=trunk/src/app/src/org/argouml/uml/diagram/state/ui/FigHistoryState.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/uml/diagram/state/ui/FigHistoryState.java     
(original)
+++ trunk/src/app/src/org/argouml/uml/diagram/state/ui/FigHistoryState.java     
2008-02-29 08:44:07-0800
@@ -88,7 +88,8 @@
      * [EMAIL PROTECTED]
      */
     @Override
-    protected void setStandardBounds(int x, int y, int w, int h) {        
+    protected void setStandardBounds(int x, int y, 
+            int width, int height) {        
        if (getNameFig() == null) {
             return;
         }

Modified: trunk/src/app/src/org/argouml/uml/diagram/ui/FigNodeModelElement.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/diagram/ui/FigNodeModelElement.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/diagram/ui/FigNodeModelElement.java&p2=trunk/src/app/src/org/argouml/uml/diagram/ui/FigNodeModelElement.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/uml/diagram/ui/FigNodeModelElement.java       
(original)
+++ trunk/src/app/src/org/argouml/uml/diagram/ui/FigNodeModelElement.java       
2008-02-29 08:44:07-0800
@@ -2020,12 +2020,15 @@
         if (modelElement != null) {
             Collection stereos = 
Model.getFacade().getStereotypes(modelElement);
 
-            if (getStereotypeView() == 
DiagramAppearance.STEREOTYPE_VIEW_BIG_ICON
-                    && (stereos == null || stereos.size() != 1 ||
-                            (stereos
-                            .size() == 1 && getProject()
-                            .getProfileConfiguration().getFigNodeStrategy()
-                            .getIconForStereotype(stereos.iterator().next()) 
== null))) {
+            if (getStereotypeView() 
+                    == DiagramAppearance.STEREOTYPE_VIEW_BIG_ICON
+                    && (stereos == null 
+                            || stereos.size() != 1 
+                            ||  (stereos.size() == 1 
+                                    && getProject().getProfileConfiguration()
+                                    .getFigNodeStrategy().getIconForStereotype(
+                                            stereos.iterator().next()) 
+                                            == null))) {
                 practicalView = DiagramAppearance.STEREOTYPE_VIEW_TEXTUAL;
             }
             return practicalView;

Modified: 
trunk/src/app/src/org/argouml/uml/diagram/ui/FigStereotypesCompartment.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/diagram/ui/FigStereotypesCompartment.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/diagram/ui/FigStereotypesCompartment.java&p2=trunk/src/app/src/org/argouml/uml/diagram/ui/FigStereotypesCompartment.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/uml/diagram/ui/FigStereotypesCompartment.java 
(original)
+++ trunk/src/app/src/org/argouml/uml/diagram/ui/FigStereotypesCompartment.java 
2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 1996-2007 The Regents of the University of California. All
+// Copyright (c) 1996-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -372,11 +372,11 @@
     /**
      * Turn on/off textual stereotype display in preference to icon.
      * 
      * @param hidingStereotypesWithIcon true to hide textual stereotypes and
      *                show icon instead.
      */
-    public void setHidingStereotypesWithIcon(boolean 
hidingStereotypesWithIcon) {
-        this.hidingStereotypesWithIcon = hidingStereotypesWithIcon;
+    public void setHidingStereotypesWithIcon(boolean hideStereotypesWithIcon) {
+        this.hidingStereotypesWithIcon = hideStereotypesWithIcon;
         updateHiddenStereotypes();
     }
     
@@ -372,11 +372,11 @@
      * Turn on/off textual stereotype display in preference to icon.
      * 
-     * @param hidingStereotypesWithIcon true to hide textual stereotypes and
+     * @param hideStereotypesWithIcon true to hide textual stereotypes and
      *                show icon instead.
      */

Modified: trunk/src/app/src/org/argouml/uml/ui/TabStyle.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/ui/TabStyle.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/ui/TabStyle.java&p2=trunk/src/app/src/org/argouml/uml/ui/TabStyle.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/uml/ui/TabStyle.java  (original)
+++ trunk/src/app/src/org/argouml/uml/ui/TabStyle.java  2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 1996-2007 The Regents of the University of California. All
+// Copyright (c) 1996-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -329,7 +329,9 @@
 
         classNs.popNamespaceElement();
 
-        String[] bases = new String[] { classNs.toString(), baseNs.toString() 
};
+        String[] bases = new String[] {
+                classNs.toString(), baseNs.toString() 
+        };
         for (String stylePanelName : stylePanelNames) {
             for (String baseName : bases) {
                 String name = baseName + "." + stylePanelName

Modified: trunk/src/app/src/org/argouml/uml/ui/UMLModelElementListModel2.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/ui/UMLModelElementListModel2.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/ui/UMLModelElementListModel2.java&p2=trunk/src/app/src/org/argouml/uml/ui/UMLModelElementListModel2.java&r1=14167&r2=14168
==============================================================================
--- trunk/src/app/src/org/argouml/uml/ui/UMLModelElementListModel2.java 
(original)
+++ trunk/src/app/src/org/argouml/uml/ui/UMLModelElementListModel2.java 
2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 2002-2007 The Regents of the University of California. All
+// Copyright (c) 2002-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -108,12 +108,12 @@
      *
      * @param name the name of the event to listen to, which triggers us
      *             to update the list model from the UML data
      * @param metaType the type of model element that the list model
      *                 is designed to contain.
      */
-    public UMLModelElementListModel2(String name, Object metaType) {
+    public UMLModelElementListModel2(String name, Object theMetaType) {
         super();
-        this.metaType = metaType;
+        this.metaType = theMetaType;
         eventName = name;
     }
     
@@ -122,19 +122,19 @@
      *
      * @param name the name of the event to listen to, which triggers us
      *             to update the list model from the UML data
      * @param metaType the type of model element that the list model
      *                 is designed to contain.
      * @param reverseDropConnection tells the JList to reverse the
      *              connection made and drop during dnd.
      */
     public UMLModelElementListModel2(
            String name, 
-           Object metaType, 
-           boolean reverseDropConnection) {
+           Object theMetaType, 
+           boolean reverseTheDropConnection) {
         super();
-        this.metaType = metaType;
+        this.metaType = theMetaType;
         eventName = name;
-        this.reverseDropConnection = reverseDropConnection;
+        this.reverseDropConnection = reverseTheDropConnection;
     }
     
     /**

Modified: 
trunk/src/app/src/org/argouml/uml/ui/foundation/extension_mechanisms/PropPanelStereotype.java
Url: 
http://argouml.tigris.org/source/browse/argouml/trunk/src/app/src/org/argouml/uml/ui/foundation/extension_mechanisms/PropPanelStereotype.java?view=diff&rev=14168&p1=trunk/src/app/src/org/argouml/uml/ui/foundation/extension_mechanisms/PropPanelStereotype.java&p2=trunk/src/app/src/org/argouml/uml/ui/foundation/extension_mechanisms/PropPanelStereotype.java&r1=14167&r2=14168
==============================================================================
--- 
trunk/src/app/src/org/argouml/uml/ui/foundation/extension_mechanisms/PropPanelStereotype.java
       (original)
+++ 
trunk/src/app/src/org/argouml/uml/ui/foundation/extension_mechanisms/PropPanelStereotype.java
       2008-02-29 08:44:07-0800
@@ -1,5 +1,5 @@
 // $Id$
-// Copyright (c) 1996-2007 The Regents of the University of California. All
+// Copyright (c) 1996-2008 The Regents of the University of California. All
 // Rights Reserved. Permission to use, copy, modify, and distribute this
 // software and its documentation without fee, and without a written
 // agreement is hereby granted, provided that the above copyright notice
@@ -255,7 +255,7 @@
      *
      * @author Michiel
      */
-    class ActionAddStereotypeBaseClass extends AbstractActionAddModelElement2{
+    class ActionAddStereotypeBaseClass extends AbstractActionAddModelElement2 {
 
         @Override
         protected List getChoices() {

---------------------------------------------------------------------
@@ -108,12 +108,12 @@
      * @param name the name of the event to listen to, which triggers us
      *             to update the list model from the UML data
-     * @param metaType the type of model element that the list model
+     * @param theMetaType the type of model element that the list model
      *                 is designed to contain.
      */
@@ -122,19 +122,19 @@
      * @param name the name of the event to listen to, which triggers us
      *             to update the list model from the UML data
-     * @param metaType the type of model element that the list model
+     * @param theMetaType the type of model element that the list model
      *                 is designed to contain.
@@ -122,19 +122,19 @@
      *                 is designed to contain.
-     * @param reverseDropConnection tells the JList to reverse the
+     * @param reverseTheDropConnection tells the JList to reverse the
      *              connection made and drop during dnd.
      */
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]

Reply via email to